==============
oceanum-python
==============


.. image:: https://img.shields.io/pypi/v/oceanum.svg
        :target: https://pypi.python.org/pypi/oceanum

.. image:: https://img.shields.io/travis/oceanum/oceanum.svg
        :target: https://travis-ci.org/oceanum/oceanum

.. image:: https://readthedocs.org/projects/oceanum/badge/?version=latest
        :target: https://oceanum.readthedocs.io/en/latest/?badge=latest
        :alt: Documentation Status


Library for oceanum.io services


* MIT license
* Documentation: https://oceanum.readthedocs.io.


Features
--------

* Simple pythonic access to the Oceanum datamesh

Credits
-------

This package was developed by `Oceanum Numerical <https://www.oceanum.science>`_, with input from our development partners and contributors.
